@@ -7,7 +7,7 @@ from typing import Any, Tuple
 
 from app.dynamodb import csv_import, csv_export, truncate
 
-__version__ = "1.3.4"
+__version__ = "1.4.3"
 config_file = "config.ini"
 
 
@@ -53,7 +53,10 @@ def execute() -> Tuple:
     # csv export
     if args.exp:
         if args.output is not None:
-            result = csv_export(table, args.output)
+            parameters = {}
+            if args.index is not None:
+                parameters["IndexName"] = args.index
+            result = csv_export(table, args.output, parameters)
         else:
             return ("Export mode requires a output file option.", 1)
 
@@ -86,6 +89,8 @@ def parse_args(args: str) -> Any:
         "--truncate", help="mode truncate", action="store_true")
     parser.add_argument(
         "-t", "--table", help="DynamoDB table name", required=True)
+    parser.add_argument(
+        "-idx", "--index", help="DynamoDB index name")
     parser.add_argument(
         "-f", "--file", help="UTF-8 CSV file path required import mode")
     parser.add_argument(
@@ -107,6 +112,7 @@ def config_read_and_get_table(args: Any) -> Any:
         raise ValueError(f"Please make your {config_file} file")
 
     config = configparser.ConfigParser()
+    config.optionxform = str
     config.read_dict({"AWS": {"ENDPOINT_URL": ""}})
     config.read(config_file)
 
